# Dependencies

Dependency injection support for haolib.

## Overview

The dependencies module provides integration with dependency injection frameworks.

## Components

- **Dishka**: Integration with the Dishka dependency injection framework
